---
title: Astral Adventuring
description: Notes and rules for adventuring in the astral plane.
date_pub: 2023-02-19T15:10:00-05:00
section: astral
content_type: feature
short_code: aa1
---

[[toc]]

### Astral Travel Procedure

The steps to take for each phase of astral travel:

1. **Setup**: Referee describes the situation
2. **Decide Course**: Players decide on their course of travel for the phase and any planned activities for the day.
3. **Complication Check**: Referee makes a complication check.
4. **Description**: Referee describes the regions passed through, any points of interest that the party comes across, and any complications they encounter.
5. **Actions / Responses / Complications** - Party declares actions, referee describes the results.
6. **End of Phase**: The referee updates time records.
7. **Repeat**: Return to step 2 and repeat until travel ends.

#### Complication Check

Roll 1d6, ignoring results of 4+ for the first 2 checks.

1. **Encounter**: Wandering creature or vessel, social encounter, or some other random interaction.
2. **Signs / Portents**: Indications of possible encounter nearby - could be a clue, indications of a creature nearby, etc.
3. **Locality**: Some environmental or external event that affects the PCs - psychic storm, fragment, etc.
4. **Pilot / Ship Issue**: Pilot / power source exhaustion or some other ship complication, takes 1d6 shifts to resolve and resume travel (50% chance the ship will have to remain in dock for 1d6 phases to make additional repairs).
5. **Lose Direction**: Each phase spent moving in the wrong direction adds 1d4-1 additional phases of travel.
6. **No Complications**

**Distance**

-   Astral encounters between ships usually start 1400 + (1d6 x 100) yards out (about a mile, the distance at which two ships will pull each other out of travel speed).
-   Wandering creatures are encountered 4d6 × 10 yards away, and are usually not surprised by astral vessels.
    -   If either side is surprised (see [Encounter procedure](/rules/adventuring.html#encounter-procedure)), this is reduced to 1d4 × 10 yards.

**Location**: Astral encounters may occur either in the open astral plane or on land (such as a fragment, island, or dock), if the party lands or docks at some point during the day.

**Frequency of Check**

-   In the deep astral, check once every other day (once every 6 phases, roll 1d6 to determine which phase).
-   Near a [port](#portals) or [outpost](#outposts) (within 1-2 days travel), check once per day, or even once per phase (for busy outposts).

### Currents

Invisible flows of psychic energy that permeate and swirl around the astral plane.

-   Creatures move up to 10x faster when moving with the current (or faster).
-   Vessels designed to ride on these currents are called **astral cruisers**.
    -   They can use the currents to move at [travel speed](/astral/vessels#travel-speedl).

### Distance and Measurement

-   Ranges are measured in yards, rather than feet (3x increase).
-   Areas of spell effects, blasts, etc. are still measured in feet.
-   Movement rates:
    -   For creatures - measured in feet.
    -   For vessels - measured in yards.

#### Missile Weapons

-   Gain an additional attack range option, **Distant**:
    -   -4 to attack rolls.
    -   Range is 1 mile.

<!--
### Chases

#### Evading

Evasion chance is determined by difference between the movement rates of the two sides’, listed in the table below.

-   **Success**: Pursuers lose track of fleeing side, can't catch up until next day (and only as a random encounter).

-   **Failure**: Continue to **Pursuit**.

#### Pursuit

-   Time passes in rounds.
-   Pursuit begins at normal encounter distance.
-   Pursuing side closes in on fleeing side
    -   Distance between sides decreases by the difference between their movement rates (minimum 30' per round).

#### Ship-Based Evasion

-   Vessels use the same table, replacing feet with yards in the measurements speed.

<div class="dividedTableWrapper">

| Fleeing Side’s Movement Rate           | Chance of Evasion |
| -------------------------------------- | ----------------- |
| Faster than pursuer                    | 80%               |
| 0’–30’ per round slower than pursuer   | 50%               |
| 31’–60’ per round slower than pursuer  | 40%               |
| 61’–90’ per round slower than pursuer  | 35%               |
| 91’–120’ per round slower than pursuer | 25%               |
| 121’+ per round slower than pursuer    | 10%               |

[Astralborne Evasion Chance]

</div>
-->

### Fragments

Pieces of other planes (usually floating) in the astral plane. The shape is typically determined by the plane of origin:

-   **Fire**: Fragments from [the elemental plane of fire](/planes/elemental.html) are usually globes of elemental fire (used in Dwarven fire engines and some Drahki weapons).
-   **Water**: Fragments from [the elemental plane of water](/planes/elemental.html) are usually globes of water.
-   **Earth**: Fragments from [the elemental plane of earth](/planes/elemental.html) are usually irregularly-shaped chunks of rock and dirt.
    -   Large fragments of earth are called **islands**, and often used to support a stronghold or outpost in the astral void.
-   **Air**: Fragments from [the elemental plane of air](/planes/elemental.html) are usually globes of air (used to supply some ships traveling to airless planes)
-   **Chaos**: Fragments from [the elemental plane of chaos](/planes/elemental.html) are usually jet black globes, and tend to function as spheres of annihilation.
-   **Law**: Fragments from [the elemental plane of law](/planes/elemental.html) are usually globes of crackling, radiant energy.
    -   It's believed that these arise spontaneously when a fragment from the plane of chaos appears, and are equal in size to the chaos ones.
    -   When a fragment of law and chaos are combined, the resulting release of energy looks like white and black lightning, and can be seen for thousands of miles around.

### Gravity

-   Subjective, with capable creatures (INT 5 or greater) able to change "down" with a thought (CHA check if under duress).
    -   Falling speed is INT x 30' / combat round, specific maneuvers require a CHA check.
-   Objects float in space unless able to move on their own (as above) or acted upon by an external force.
-   Unintelligent creatures fall "down" at 100' / round.

### Languages

-   Alignment languages are the same throughout the multiverse.
-   The same version of Common is spoken throughout the multiverse, with only the perceived accent of a speaker changing (along with certain slang).
-   Each racial language spoken and written on a given plane is a dialect of that same language on other planes.

### Outposts

A stronghold, shop, or town in the astral plane, usually established on a large island.

-   Those interested in trade will have one (or more) docks for passing ships.
-   Outposts with [permanent portals](#portals) to other planes are called **ports**.

### Psychic Clouds

Thin streams of psychic "vapor", hundreds to thousands of miles across, which appear as clouds when viewed from distance.

-   Psychic Storms are enormous storms of psychic energy which can disable a ship as well as its crew. Often found crawling with astral zombies. Best to avoid.

### Portals

Usually manifest as flat, shimmering discs of various colors that appear to float in place.

-   Can be used by passing through to arrive on the destination plane.
-   May lead to any other plane (Inner, Outer, or Material).
-   Each different destination has its own color, and a portal leading to a character's home plane will always look silver to them.
-   Most portals (99%) are temporary, lasting 1d20 hours.
-   Most portals (99%) are one-way, and only visible (when open) from the entry side, but become two-way for 1d4 rounds after being passed through.
-   An open portal may be be closed or made translucent (allowing characters to see the other end for one turn) with a successful CHA check within 60' of the portal.
-   Temporary portals which lead from the astral to other planes are called **pools**.
-   Permanent portals which lead from the astral to other planes are called **ports**, and are usually established on a island and attached to an [outpost](#outposts).

### Surprise

Wandering astral creatures are not usually surprised by traveling vessels. Special circumstances (ex: thick astral clouds, or a psychic storm) may alter this.

### Temperature

The ambient temperature in the astral plane tends towards the tepid side for most humans and demihumans, being roughly equivalent to a warm spring day in a temperate climate.

### Time

-   Time is quickened: 3 rounds pass in the astral plane for each round that passes in a Material Plane.
-   Spells cast in the Astral plane appear to last 3 times as long as listed
-   The effects of time don't happen while on the astral plane. This means that characters in the Astral Plane:
    -   do not age,
    -   do not need to breathe,
    -   do not need to eat or drink (which also means that they can't expend a ration to heal), and
    -   only need to sleep for 30 phase-minutes each phase, although they still need to rest for an entire shift (8 phase-hours), and only gain 1 HP back after resting and sleeping.

### Travel

Travel by astral cruiser (via the [astral currents](#astral-currents)) to any known location within the astral plane usually takes 3-30 days.

-   Travel between most ports under the control of the Astral Trade Union only takes 1d6+2 days.
-   Without a ship, the vast distances between landmarks means one could go for weeks, months, or even years before coming across anyone (or anything) else.
-   It takes 1 turn for a ship to dock, and 1 turn for it to disembark.
-   An astral cruiser cannot travel by currents while within 1 mile of another active vessel or large astral body (like an island).
    -   If a cruiser comes within a mile of a large astral object while traveling. it will automatically reduce its speed to normal movement (in yards).

### Visibility

-   An astral body (such as a [fragment](#fragments), island, or even a dead god) may be spotted at a distance of hundreds of miles (based on its size).
-   Vessels (and large creatures) may be sighted at great distances by the contrails they leave behind in the psychic clouds that permeate the plane.
    -   Identification is usually limited to tactical range (approximately 1 mile) in the open astral plane, or as little as 100 yards in a psychic storm.
