---
title: 'HOSR Core Rules: Combat'
description: The rules for running combat in HOSR.
date_pub: 2023-04-22T16:42:00-04:00
section: rules
content_type: feature
short_code: uhc
---

[[toc]]

### Combat Procedure

Adventurers tend to die easily, so most combat should be avoided unless the adventurers have a clear advantage.

That having been said, fights do occur, and when they do, the following steps are performed:

1. **Declare Spells, Defending, Retreats, and Versatile Weapons**: Players declare if they will _cast a spell_, _defend_, or _retreat_ this round (and, if so, which type of retreat), and characters wielding [Versatile](#weapon-properties) weapons declare if they will deal extra damage.
2. **Roll Initiative**: Each side that can attack rolls 1d20, highest roll attacks first.
3. **Winning Side Actions**: Each character or monster gets a move and an action, with either one occurring first.

    - **Morale Check**: Monsters who've been severely wounded or seen their leaders killed may flee. Roll 2d6 under morale score or the monsters surrender / flee.
    - **Move**: Move up to full speed
        - If prone, use 1/2 movement to stand up.
        - If _engaged_ with an enemy at the start of the move, make a _fighting retreat_ or they get a free attack.
    - **Action**: Do something, like _attack_, _defend_, _cast a spell_, or stowe an item.
        - Spellcasters can't move after casting a spell.

4. **Change Sides**: Opposing side becomes active.
5. **Slow Weapons**: Resolve any slow weapons or end-of-round abilities.
6. **Repeat**: Return to step 2 and repeat until only one side remains.

### Readying Weapons

-   Available weapons may be readied for free while moving (if hands are empty or currently held items are dropped).
-   Stowing held weapons takes a full action.

### Attacking

Roll 1d20 plus any appropriate modifiers. If it equals or beats the target's AC, roll for damage (again including any appropriate modifiers).

-   +2 bonus to hit from behind.

-   When mounted, +1 bonus to hit most foes on foot.

#### AC

-   Character AC is usually determined by type of **armor** worn.
-   **Shields** grant +1 AC when used.
    -   Can also be destroyed to prevent a hit from inflicting damage.

<div class="dividedTableWrapper">

| Armor Type | AC  |
| :--------: | :-: |
|    None    | 10  |
|    Hide    | 11  |
|  Leather   | 12  |
|  Studded   | 13  |
| Chainmail  | 14  |
| Half-Plate | 15  |
| Full Plate | 16  |

[Standard Armor AC]

</div>

#### Melee Attacks

Melee attack rolls are modified based on the character's Strength.

<div class="dividedTableWrapper">

|  STR  | Mod |
| :---: | :-: |
|   3   | -3  |
|  4-5  | -2  |
|  6-8  | -1  |
| 9-12  | +0  |
| 13-15 | +1  |
| 16-17 | +2  |
|  18+  | +3  |

[Strength Modifier]

</div>

-   Melee attacks are usually limited to 5' range.
-   Characters in melee combat with each other or other monsters are said to be **engaged**.
-   Unarmed attacks do 1d2 damage by default.

##### Dual Wielding

PCs with DEX 13+ can dual wield certain weapons.

-   When using 2 Light weapons, may make an attack with each one.
-   When using a one-handed weapon and a Light weapon, may only make one attack, but +1 to the attack and damage rolls.

#### Missile Attacks

Missile attack rolls are modified based on the character's Dexterity, the target's cover, and the range to the target.

<div class="dividedTableWrapper">

|  DEX  | Mod |
| :---: | :-: |
|   3   | -3  |
|  4-5  | -2  |
|  6-8  | -1  |
| 9-12  | +0  |
| 13-15 | +1  |
| 16-17 | +2  |
|  18+  | +3  |

[Dexterity Modifier]

</div>

-   -1 to -4 penalties may apply when attacking targets behind partial cover.
    -   Targets behind total cover cannot be hit.
-   The range of missile attacks are usually determined by the type of missile used.
    -   Attacks beyond long range are not possible.

<div class="dividedTableWrapper">

| Range  | Mod |
| :----: | :-: |
| Short  | +1  |
| Medium | --  |
|  Long  | -1  |

[Range Modifier]

</div>

#### Critical Hits

A natural 20 on an attack is a critical hit. Roll 1d20 on the Critical Hit Table to see what additional effect occurs.

<div class="dividedTableWrapper">

| 1d20 |               Effect               |
| :--: | :--------------------------------: |
| 1-2  |             Max Damage             |
|  3   |    Max Damage + Free Attack[^1]    |
|  4   |   Max Damage + Target Fumble[^2]   |
|  5   |  Max Damage + Target Blinded[^3]   |
|  6   |           Double Damage            |
|  7   |  Double Damage + Free Attack[^1]   |
|  8   | Double Damage + Target Fumble[^2]  |
|  9   | Double Damage + Target Blinded[^3] |
|  10  |         Double Max Damage          |
|  11  |           Triple Damage            |
|  12  |  Triple Damage + Free Attack[^1]   |
|  13  | Triple Damage + Target Fumble[^2]  |
|  14  | Triple Damage + Target Blinded[^3] |
|  15  |         Triple Max Damage          |
|  16  |        Quadruple Max Damage        |
|  17  |   Max Damage + Armor Damaged[^4]   |
|  18  | Max Damage + Target Amputation[^5] |
|  19  |  Max Damage + Target Stunned[^6]   |
|  20  |       Save vs. Death or die        |

[Critical Hit Table]

[^1]: **Free Attack**: Attempt another hit with same weapon
[^2]: **Target Fumble**: Target must roll on fumble table
[^3]: **Target Blinded**: Blood or debris blinds target for 1d4 rounds
[^4]: **Armor Damaged**: Reduce target's AC by 1 until armor repaired / healed
[^5]: **Target Amputation**: Target loses an appendage.
[^6]: **Target Stunned**: Blow stuns target for 1d6 rounds

</div>

#### Fumbles

A natural 1 on an attack is a fumble. Roll 1d20 on the Fumble Table to see what additional effect occurs.

<div class="dividedTableWrapper">

| 1d20 |                         Effect                         |
| :--: | :----------------------------------------------------: |
|  1   |                 Stumble, weapon breaks                 |
|  2   | Stumble, automatic hit on closest ally within 10'[^1]  |
|  3   | Stumble, next attack against is automatic critical hit |
|  4   |     Stumble, can't attacks until end of next round     |
|  5   |         Stumble, can't attack until next round         |
|  6   |     Stumble, next attack against is automatic hit      |
|  7   |        Stumble, hit self for maximum damage[^1]        |
|  8   |        Stumble, hit self for regular damage[^1]        |
|  9   |          Stumble, all rolls next round get -2          |
|  10  |       Stumble, go last in initiative next round        |
|  11  |       Fall down (prone) and drop weapon 30' away       |
|  12  |       Fall down (prone) and drop weapon 20' away       |
|  13  |       Fall down (prone) and drop weapon 10' away       |
|  14  |        Fall down (prone) and drop weapon nearby        |
|  15  |                   Fall down (prone)                    |
|  16  |                  Drop weapon 30' away                  |
|  17  |                  Drop weapon 20' away                  |
|  18  |                  Drop weapon 10' away                  |
|  19  |                  Drop weapon at feet                   |
|  20  |            Fumble weapon, but maintain hold            |

[Fumble Table]

[^1]: **Automatic Hits**: Roll 1d20 to check for critical, but ignore further fumbles.

</div>

### Defending

Spend a round fighting defensively (parrying, blocking, dodging, feinting, etc.). Gets +2 AC. Can be used with **Fighting Retreat**.

### Movement

Most characters can move 40' in a combat round.

-   **When Engaged**: Can't move away from foe without retreating.
-   **When Prone**: Use 1/2 movement to stand up.

### Retreating

Engaged characters that wish to move away can either make a fighting retreat, or a full retreat.

-   **Fighting Retreat**: Can move backwards at 1/2 their normal movement rate and take an attack or defend action, while avoiding giving enemies a free attack.
-   **Full Retreat**: Turning and fleeing from combat at their full movement rate, enemies can make a free attack at +2 bonus.

### Weapons

#### Melee Weapons

<div class="dividedTableWrapper">

|             Weapon              | Damage |      [Properties](#weapon-properties)      |
| :-----------------------------: | :----: | :----------------------------------------: |
|            Battleaxe            |  1d8   |              Versatile (1d10)              |
|              Club               |  1d4   |                Blunt, Light                |
|             Dagger              |  1d4   |      Light, Thrown (10' / 20' / 30')       |
|              Flail              |  1d6   |                                            |
|           Greatsword            |  1d10  |          Reach, Slow, Two-handed           |
|            Greatclub            |  1d8   |          Blunt, Slow, Two-handed           |
|            Hand Axe             |  1d6   |      Light, Thrown (10' / 20' / 30')       |
|             Javelin             |  1d6   |          Thrown (30'/ 60' / 90')           |
|              Lance              |  1d6   |                   Charge                   |
|          Light Hammer           |  1d4   |   Blunt, Light, Thrown (10' / 20' / 30')   |
|            Longsword            |  1d8   |              Versatile (1d10)              |
|              Mace               |  1d6   |                   Blunt                    |
|           Morningstar           |  1d8   |                                            |
|            Nunchaku             |  2d4   |             Blunt, Two-handed              |
|             Pickaxe             |  1d8   |              Slow, Two-handed              |
| Polearm (Glaive, Halberd, Pike) |  1d10  |          Reach, Slow, Two-handed           |
|          Quarterstaff           |  1d4   |           Blunt, Versatile (1d6)           |
|             Rapier              |  1d8   |                                            |
|            Scimitar             |  1d6   |                                            |
|             Sickle              |  1d4   |                   Light                    |
|           Shortsword            |  1d6   |                                            |
|              Spear              |  1d6   | Thrown (20' / 40' / 60') , Versatile (1d8) |
|             Trident             |  1d6   | Thrown (10' / 20' / 30') , Versatile (1d8) |
|            Warhammer            |  1d6   |           Blunt, Versatile (1d8)           |
|              Whip               |  1d4   |                   Reach                    |

[Melee Weapon Table]

</div>

#### Ranged Weapons

<div class="dividedTableWrapper">

|     Weapon      | Damage |       Range       | [Properties](#weapon-properties) |
| :-------------: | :----: | :---------------: | :------------------------------: |
|     Blowgun     |   1    | 25' / 50' / 100'  |              Reload              |
| Crossbow, Hand  |  1d4   |  20' / 40' / 80'  |          Light, Reload           |
| Crossbow, Heavy |  1d8   | 80' / 160' / 240' |     Reload, Slow, Two-handed     |
| Crossbow, Light |  1d6   | 40' / 80' / 120'  |        Reload, Two-handed        |
|    Great Bow    |  1d8   | 70' / 140' / 210' |         Slow, Two-handed         |
|     Longbow     |  1d6   | 70' / 140' / 210' |            Two-handed            |
|    Shortbow     |  1d6   | 50' / 100' / 150' |            Two-handed            |
|      Sling      |  1d4   | 40' / 80' / 160'  |              Blunt               |

[Ranged Weapon Table]

</div>

#### Weapon Properties

-   **Blunt**: Can be wielded by cleric.
-   **Charge**: Doubles any damage done after moving at least 60' while mounted before attacking.
-   **Light**: May be used in offhand when [dual-wielding](#dual-wielding).
-   **Reach**: Grants a extra 5' reach for determining melee range.
-   **Reload**: Takes a round to reload, can only be fired every other round.
-   **Slow**: Always attacks last in a round.
-   **Thrown**: May be used as ranged weapon (short, medium, and long range indicated).
-   **Two-handed**: Requires two hands to use.
-   **Versatile**: May gain _Slow_ and _Two-handed_ to deal indicated damage.

!!!include(license/wotc-cc-by.md)!!!
